==> xl-react-components-0.16.62.tgz: package/tests/e2e/dsl/component/widget/widget-autocomplete.js <==
import KeyCodes from 'keycode-js';
import {Action, ActionUtil, Expectation, WaitCondition} from 'protractor-base-dsl';
import XlComponent from '../base/xl-component';

export const inputSelector = '.testComponent .xl-react-autocomplete-container input';
export const autocompleteSpinnerSelector =
    '.testComponent .xl-react-autocomplete-suggestion-list-container .xl-react-widget-spinner-container';

export const clickEnterOnInput = () =>
    Action.keyDown(inputSelector, KeyCodes.KEY_RETURN);

export const clickOnInput = () =>
    Action.click('.testComponent .xl-react-autocomplete-container input');

export const clickOnLabel = () =>
    Action.clickIfClickable('.testComponent label');

export const clearSelection = () => {
    const containerSelector = '.testComponent .xl-react-autocomplete-container';
    const action = () => Action.click(`${containerSelector} .xl-react-btn-close`);
    const condition = () => WaitCondition.textEquals(`${containerSelector} input`, '');
    ActionUtil.repeatAction(action, condition);
};

export const expectDisabled = () =>
    Expectation.disabled('.testComponent .xl-react-autocomplete-container input');

export const expectEnabled = () =>
    Expectation.enabled('.testComponent .xl-react-autocomplete-container input');

export const expectEmptyInputValue = () =>
    Expectation.attributeContainsValue(inputSelector, 'value', '');

export const expectSuggestionValue = (optionNumber, optionText) => {
    const suggestionOption = `.xl-react-autocomplete-suggestion:nth-child(${optionNumber}) > div`;
    const optionSelector = `.testComponent .xl-react-autocomplete-suggestion-list ${suggestionOption}`;
    return Expectation.textEquals(optionSelector, optionText);
};

export const expectSuggestionNotPresent = (optionNumber) => {
    const suggestionOption = `.xl-react-autocomplete-suggestion:nth-child(${optionNumber}) > div`;
    Expectation.notPresent(`.testComponent .xl-react-autocomplete-suggestion-list ${suggestionOption}`);
};

export const expectSuggestionListIsPresent = () =>
    Expectation.displayed('.testComponent .xl-react-autocomplete-suggestion-list');

export const expectSuggestionListNotPresent = () =>
    Expectation.notPresent('.testComponent .xl-react-autocomplete-suggestion-list');

export const expectClearSelectionPresent = () =>
    Expectation.present('.testComponent .xl-react-autocomplete-container .xl-react-btn-close');

export const expectClearSelectionNotPresent = () =>
    Expectation.notPresent('.testComponent .xl-react-autocomplete-container .xl-react-btn-close');

export const expectValue = (value) =>
    Expectation.attributeContainsValue(inputSelector, 'value', value);

export const expectSpinnerPresent = () =>
    Expectation.present(autocompleteSpinnerSelector);

export const expectSpinnerNotPresent = () =>
    Expectation.notPresent(autocompleteSpinnerSelector);

export const waitForSpinner = () => {
    expectSpinnerPresent();
    expectSpinnerNotPresent();
};

export const expectEmptyValue = () => expectValue('');

export const openSelection = () => {
    const containerSelector = '.testComponent .xl-react-autocomplete-container';
    const action = () => Action.click(`${containerSelector} .show-all`);
    const condition = () => WaitCondition.present(`${containerSelector} .resize-triggers`);
    return ActionUtil.repeatAction(action, condition);
};

export const selectOption = (optionNumber) => {
    const suggestionOption = `.xl-react-autocomplete-suggestion:nth-child(${optionNumber}) div`;
    return Action.click(`.testComponent .xl-react-autocomplete-suggestion-list ${suggestionOption}`);
};

export const setValue = (value) => {
    const action = () => Action.typeText(inputSelector, value);
    const condition = () => WaitCondition.textEquals(inputSelector, value);
    return ActionUtil.repeatAction(action, condition);
};

const WidgetAutocomplete = {
    ...XlComponent,
    clickEnterOnInput,
    clickOnInput,
    clickOnLabel,
    clearSelection,
    expectDisabled,
    expectEnabled,
    expectEmptyInputValue,
    expectSuggestionValue,
    expectSuggestionNotPresent,
    expectSuggestionListIsPresent,
    expectSuggestionListNotPresent,
    expectClearSelectionPresent,
    expectClearSelectionNotPresent,
    expectSpinnerPresent,
    expectSpinnerNotPresent,
    inputSelector,
    expectValue,
    expectEmptyValue,
    openSelection,
    selectOption,
    setValue,
    waitForSpinner
};

export default WidgetAutocomplete;

global.WidgetAutocomplete = WidgetAutocomplete;

==> xl-react-components-0.18.103.tgz: package/tests/e2e/dsl/component/widget/widget-autocomplete.js <==
import KeyCodes from 'keycode-js';
import {Action, ActionUtil, Expectation, WaitCondition} from 'protractor-base-dsl';
import R from 'ramda';
import XlComponent from '../base/xl-component';

export const inputSelector = '.testComponent .xl-react-autocomplete-container input';
export const autocompleteSpinnerSelector =
    '.testComponent .xl-react-autocomplete-suggestion-list-container .xl-react-widget-spinner-container';

export const clickEnterOnInput = () =>
    Action.keyDown(inputSelector, KeyCodes.KEY_RETURN);

export const clickOnInput = () =>
    Action.click('.testComponent .xl-react-autocomplete-container input');

export const clickOnLabel = () =>
    Action.clickIfClickable('.testComponent label');

export const clearSelection = () => {
    const containerSelector = '.testComponent .xl-react-autocomplete-container';
    const action = () => Action.click(`${containerSelector} .xl-react-btn-close`);
    const condition = () => WaitCondition.textEquals(`${containerSelector} input`, '');
    ActionUtil.repeatAction(action, condition);
};

export const expectDisabled = () =>
    Expectation.disabled('.testComponent .xl-react-autocomplete-container input');

export const expectEnabled = () =>
    Expectation.enabled('.testComponent .xl-react-autocomplete-container input');

export const expectEmptyInputValue = () =>
    Expectation.attributeContainsValue(inputSelector, 'value', '');

export const expectSuggestionValue = (optionNumber, optionText) => {
    const suggestionOption = `.xl-react-autocomplete-suggestion:nth-child(${optionNumber}) > div`;
    const optionSelector = `.testComponent .xl-react-autocomplete-suggestion-list ${suggestionOption}`;
    return Expectation.textEquals(optionSelector, optionText);
};

export const expectSuggestionNotPresent = (optionNumber) => {
    const suggestionOption = `.xl-react-autocomplete-suggestion:nth-child(${optionNumber}) > div`;
    Expectation.notPresent(`.testComponent .xl-react-autocomplete-suggestion-list ${suggestionOption}`);
};

export const expectSuggestionListIsPresent = () =>
    Expectation.displayed('.testComponent .xl-react-autocomplete-suggestion-list');

export const expectSuggestionListNotPresent = () =>
    Expectation.notPresent('.testComponent .xl-react-autocomplete-suggestion-list');

export const expectClearSelectionPresent = () =>
    Expectation.present('.testComponent .xl-react-autocomplete-container .xl-react-btn-close');

export const expectClearSelectionNotPresent = () =>
    Expectation.notPresent('.testComponent .xl-react-autocomplete-container .xl-react-btn-close');

export const expectValue = (value) =>
    Expectation.attributeContainsValue(inputSelector, 'value', value);

export const expectSpinnerPresent = () =>
    Expectation.present(autocompleteSpinnerSelector);

export const expectSpinnerNotPresent = () =>
    Expectation.notPresent(autocompleteSpinnerSelector);

export const waitForSpinner = () => {
    expectSpinnerPresent();
    expectSpinnerNotPresent();
};

export const expectEmptyValue = () => expectValue('');

export const openSelection = () => {
    const containerSelector = '.testComponent .xl-react-autocomplete-container';
    const action = () => Action.click(`${containerSelector} .with-search`);
    const condition = () => WaitCondition.present(`${containerSelector} .resize-triggers`);
    return ActionUtil.repeatAction(action, condition);
};

export const selectOption = (optionNumber) => {
    const suggestionOption = `.xl-react-autocomplete-suggestion:nth-child(${optionNumber}) div`;
    return Action.click(`.testComponent .xl-react-autocomplete-suggestion-list ${suggestionOption}`);
};

export const setValue = (value) => {
    const action = () => Action.typeText(inputSelector, value);
    const condition = () => WaitCondition.textEquals(inputSelector, value);
    return ActionUtil.repeatAction(action, condition);
};

export const toggleStrictValidation = () => {
    const toggleLineElement = element.all(By.css('.testBindings > div > .label'))
        .filter((elem) => elem.getText().then((labelText) =>
            R.equals(labelText, 'Strict validation')
        ))
        .first();

    const toggleElement = toggleLineElement
        .element(By.xpath('.//parent::div'))
        .element(By.css('input[type="checkbox"]'));

    Action.jsClick(toggleElement);
};

const WidgetAutocomplete = {
    ...XlComponent,
    clickEnterOnInput,
    clickOnInput,
    clickOnLabel,
    clearSelection,
    expectDisabled,
    expectEnabled,
    expectEmptyInputValue,
    expectSuggestionValue,
    expectSuggestionNotPresent,
    expectSuggestionListIsPresent,
    expectSuggestionListNotPresent,
    expectClearSelectionPresent,
    expectClearSelectionNotPresent,
    expectSpinnerPresent,
    expectSpinnerNotPresent,
    inputSelector,
    expectValue,
    expectEmptyValue,
    openSelection,
    selectOption,
    setValue,
    toggleStrictValidation,
    waitForSpinner
};

export default WidgetAutocomplete;

global.WidgetAutocomplete = WidgetAutocomplete;
